@@ -20,7 +20,6 @@
 #include <znc/User.h>
 #include <znc/IRCNetwork.h>
 #include <znc/Query.h>
-#include <znc/ZNCDebug.h>
 
 using std::set;
 using std::map;
@@ -89,12 +88,6 @@ CClient::~CClient() {
 
 void CClient::SendRequiredPasswordNotice() {
     PutClient(":irc.znc.in 464 " + GetNick() + " :Password required");
-    if (CDebug::Debug()) {
-        PutClient(
-            ":irc.znc.in NOTICE " + GetNick() + " :*** "
-            "ZNC is presently running in DEBUG mode. Sensitive data during "
-            "your current session may be exposed to the host.");
-    }
     PutClient(
         ":irc.znc.in NOTICE " + GetNick() + " :*** "
         "You need to send your password. "
@@ -110,7 +103,8 @@ void CClient::ReadLine(const CString& sData) {
     CLanguageScope user_lang(GetUser() ? GetUser()->GetLanguage() : "");
     CString sLine = sData;
 
-    sLine.TrimRight("\n\r");
+    sLine.Replace("\n", "");
+    sLine.Replace("\r", "");
 
     DEBUG("(" << GetFullName() << ") CLI -> ZNC ["
         << CDebug::Filter(sLine) << "]");
@@ -1204,7 +1198,7 @@ bool CClient::OnPingMessage(CMessage& Message) {
     // All PONGs are generated by ZNC. We will still forward this to
     // the ircd, but all PONGs from irc will be blocked.
     if (!Message.GetParams().empty())
-        PutClient(":irc.znc.in PONG irc.znc.in " + Message.GetParams(0));
+        PutClient(":irc.znc.in PONG irc.znc.in " + Message.GetParamsColon(0));
     else
         PutClient(":irc.znc.in PONG irc.znc.in");
     return false;
@@ -1305,10 +1299,10 @@ bool CClient::OnOtherMessage(CMessage& Message) {
         CString sModCommand;
 
         if (sTarget.TrimPrefix(m_pUser->GetStatusPrefix())) {
-            sModCommand = Message.GetParams(1);
+            sModCommand = Message.GetParamsColon(1);
         } else {
             sTarget = "status";
-            sModCommand = Message.GetParams(0);
+            sModCommand = Message.GetParamsColon(0);
         }
 
         if (sTarget.Equals("status")) {
@@ -1330,7 +1324,7 @@ bool CClient::OnOtherMessage(CMessage& Message) {
             return true;
         }
 
-        CString sPatterns = Message.GetParams(0);
+        CString sPatterns = Message.GetParamsColon(0);
 
         if (sPatterns.empty()) {
             PutStatusNotice(t_s("Usage: /attach <#chans>"));
@@ -1352,7 +1346,7 @@ bool CClient::OnOtherMessage(CMessage& Message) {
             return true;
         }
 
-        CString sPatterns = Message.GetParams(0);
+        CString sPatterns = Message.GetParamsColon(0);
 
         if (sPatterns.empty()) {
             PutStatusNotice(t_s("Usage: /detach <#chans>"));
